@@ -29,7 +29,7 @@ class BrickException(Exception):
     """Base Brick Exception
 
     To correctly use this class, inherit from it and define
-    a 'msg_fmt' property. That msg_fmt will get printf'd
+    a 'message' property. That message will get printf'd
     with the keyword arguments provided to the constructor.
     """
     message = _("An unknown exception occurred.")
@@ -117,7 +117,7 @@ class TargetPortalNotFound(BrickException):
     message = _("Unable to find target portal %(target_portal)s.")
 
 
-class TargetPortalsNotFound(BrickException):
+class TargetPortalsNotFound(TargetPortalNotFound):
     message = _("Unable to find target portal in %(target_portals)s.")
 
 
